@@ -27,13 +27,12 @@ __webpage__ = 'https://github.com/set-soft'
 __company__ = 'Instituto Nacional de Tecnologia Industrial - Argentina'
 
 # Libraries.
-import os
 import pprint
 
 # KiCost definitions.
 from .. import DistData, KiCostError, W_NOINFO, ERR_SCRAPE, W_APIFAIL
 # Distributors definitions.
-from .distributor import distributor_class, QueryCache
+from .distributor import distributor_class, QueryCache, hide_secrets
 from .log__ import debug_detailed, debug_overview, debug_obsessive, warning
 
 available = True
@@ -55,12 +54,6 @@ SPEC_NAMES = {'tolerance': 'tolerance',
               'temperature coefficient': 'temp_coeff',
               'frequency': 'frequency',
               'package / case': 'footprint'}
-ENV_OPS = {'DIGIKEY_STORAGE_PATH': 'cache_path',
-           'DIGIKEY_CLIENT_ID': 'client_id',
-           'DIGIKEY_CLIENT_SECRET': 'client_secret',
-           'DIGIKEY_CLIENT_SANDBOX': 'sandbox',
-           'DIGIKEY_CACHE_TTL': 'cache_ttl'}
-
 __all__ = ['api_digikey']
 
 
@@ -74,6 +67,7 @@ class api_digikey(distributor_class):
     # Options supported by this API
     config_options = {'client_id': str,
                       'client_secret': str,
+                      'exclude_market_place_products': bool,
                       'sandbox': bool,
                       'locale_site': ('US', 'CA', 'JP', 'UK', 'DE', 'AT', 'BE', 'DK', 'FI', 'GR', 'IE',
                                       'IT', 'LU', 'NL', 'NO', 'PT', 'ES', 'KR', 'HK', 'SG', 'CN', 'TW',
@@ -85,6 +79,10 @@ class api_digikey(distributor_class):
                                           'AUD', 'NZD', 'INR', 'DKK', 'NOK', 'SEK', 'ILS', 'CNY', 'PLN',
                                           'CHF', 'CZK', 'HUF', 'RON', 'ZAR', 'MYR', 'THB', 'PHP'),
                       'locale_ship_to_country': str}
+    # Legacy environment mapping, others will be automatically filled by `register`
+    env_prefix = 'DIGIKEY'
+    env_ops = {'DIGIKEY_STORAGE_PATH': 'cache_path',
+               'DIGIKEY_CLIENT_SANDBOX': 'sandbox'}
 
     @staticmethod
     def configure(ops):
@@ -107,13 +105,15 @@ class api_digikey(distributor_class):
                 cache_ttl = v
             elif k == 'cache_path':
                 cache_path = v
+            elif k == 'exclude_market_place_products':
+                DK_API.exclude_market_place_products = v
             elif k.startswith('locale_'):
                 DK_API.api_ops[k] = v
         if api_digikey.enabled and (DK_API.id is None or DK_API.secret is None or cache_path is None):
             warning(W_APIFAIL, "Can't enable Digi-Key without a `client_id`, `client_secret` and `cache_path`")
             api_digikey.enabled = False
         debug_obsessive('Digi-Key API configured to enabled {} id {} secret {} path {}'.
-                        format(api_digikey.enabled, DK_API.id, DK_API.secret, cache_path))
+                        format(api_digikey.enabled, hide_secrets(DK_API.id), hide_secrets(DK_API.secret), cache_path))
         if not api_digikey.enabled:
             return
         # Try to configure the plug-in
@@ -212,13 +212,5 @@ class api_digikey(distributor_class):
             raise KiCostError(msg, ERR_SCRAPE)
         return set([DIST_NAME])
 
-    @staticmethod
-    def from_environment(options, overwrite):
-        ''' Configuration from the environment. '''
-        # Configure the module from the environment
-        # The command line will overwrite it using set_options()
-        for k, v in ENV_OPS.items():
-            api_digikey._set_from_env(v, os.getenv(k), options, overwrite, api_digikey.config_options)
-
 
 distributor_class.register(api_digikey, 100)
