@@ -27,7 +27,6 @@ __webpage__ = 'https://github.com/set-soft'
 __company__ = 'Instituto Nacional de Tecnologia Industrial - Argentina'
 
 # Libraries.
-import os
 import pprint
 import requests
 import difflib
@@ -35,7 +34,7 @@ import difflib
 # KiCost definitions.
 from .. import KiCostError, DistData, W_NOINFO, ERR_SCRAPE, W_APIFAIL, W_AMBIPN
 # Distributors definitions.
-from .distributor import distributor_class, QueryCache
+from .distributor import distributor_class, QueryCache, hide_secrets
 from .log__ import debug_detailed, debug_overview, debug_obsessive, debug_full, warning, is_debug_full
 
 # Countries supported by Farnell (*.farnell.com)
@@ -97,8 +96,6 @@ SPEC_NAMES = {'power rating': 'power',
 
 # DIST_NAMES = ['cpc', 'farnell', 'newark']
 DIST_NAMES = ['farnell', 'newark']
-ENV_OPS = {'ELEMENT14_PART_API_KEY': 'key',
-           'ELEMENT14_CACHE_TTL': 'cache_ttl'}
 PRE_TERM = {'sku': 'id', 'key': 'any', 'mpn': 'manuPartNum'}
 REPLY = {'sku': 'premierFarnellPartNumberReturn', 'key': 'keywordSearchReturn', 'mpn': 'manufacturerPartNumberSearchReturn'}
 
@@ -190,7 +187,8 @@ class Element14(object):
             params['resultsSettings.offset'] = '0'
             params['resultsSettings.numberOfResults'] = '10'
         params.update(part)
-        debug_obsessive('Query params: '+pprint.pformat(params))
+        key_hide = hide_secrets(self.key)
+        debug_obsessive('Query params: '+pprint.pformat(params).replace(self.key, key_hide))
         r = requests.get(BASE_URL, params=params)
         if r.status_code != 200:
             # debug_obsessive(pprint.pformat(r.__dict__))
@@ -231,6 +229,8 @@ class api_element14(distributor_class):
     key = None
     countries = {'cpc': 'uk', 'farnell': 'uk', 'newark': 'us'}
     try_by_keyword = False
+    env_prefix = 'ELEMENT14'
+    env_ops = {'ELEMENT14_PART_API_KEY': 'key'}
 
     @staticmethod
     def configure(ops):
@@ -252,7 +252,8 @@ class api_element14(distributor_class):
         if api_element14.enabled and api_element14.key is None:
             warning(W_APIFAIL, "Can't enable Elemen14 without a `key`")
             api_element14.enabled = False
-        debug_obsessive('Element14 API configured to enabled {} key {} path {}'.format(api_element14.enabled, api_element14.key, cache_path))
+        debug_obsessive('Element14 API configured to enabled {} key {} path {}'.
+                        format(api_element14.enabled, hide_secrets(api_element14.key), cache_path))
         if not api_element14.enabled:
             return
         # Configure the cache
@@ -372,14 +373,6 @@ class api_element14(distributor_class):
             raise KiCostError(msg, ERR_SCRAPE)
         return set(DIST_NAMES)
 
-    @staticmethod
-    def from_environment(options, overwrite):
-        ''' Configuration from the environment. '''
-        # Configure the module from the environment
-        # The command line will overwrite it using set_options()
-        for k, v in ENV_OPS.items():
-            api_element14._set_from_env(v, os.getenv(k), options, overwrite, api_element14.config_options)
-
 
 # Ok, this is special case ... we should add others
 MANF_CHANGES = {'fairchild': 'onsemi'}
