@@ -30,7 +30,6 @@ __webpage__ = 'https://github.com/set-soft'
 __company__ = 'Instituto Nacional de Tecnologia Industrial - Argentina'
 
 # Libraries.
-import os
 import pprint
 import json
 import requests
@@ -39,14 +38,12 @@ import re
 # KiCost definitions.
 from .. import KiCostError, DistData, W_NOINFO, W_APIFAIL, ERR_SCRAPE
 # Distributors definitions.
-from .distributor import distributor_class, QueryCache
+from .distributor import distributor_class, QueryCache, hide_secrets
 from .log__ import debug_detailed, debug_overview, debug_obsessive, warning
 
 available = True
 
 DIST_NAME = 'mouser'
-ENV_OPS = {'MOUSER_PART_API_KEY': 'key',
-           'MOUSER_CACHE_TTL': 'cache_ttl'}
 # Mouser Base URL
 BASE_URL = 'https://api.mouser.com/api/v1.0'
 IN_STOCK = ('In stock', 'En existencias', 'A magazzino', 'Auf Lager', 'En stock', 'Em estoque', 'Na skladě',
@@ -269,6 +266,8 @@ class api_mouser(distributor_class):
     config_options = {'key': str}
     key = None
     cache = None
+    env_prefix = 'MOUSER'
+    env_ops = {'MOUSER_PART_API_KEY': 'key'}
 
     @staticmethod
     def configure(ops):
@@ -286,7 +285,8 @@ class api_mouser(distributor_class):
         if api_mouser.enabled and api_mouser.key is None:
             warning(W_APIFAIL, "Can't enable Mouser without a `key`")
             api_mouser.enabled = False
-        debug_obsessive('Mouser API configured to enabled {} key {} path {}'.format(api_mouser.enabled, api_mouser.key, cache_path))
+        debug_obsessive('Mouser API configured to enabled {} key {} path {}'.
+                        format(api_mouser.enabled, hide_secrets(api_mouser.key), cache_path))
         if not api_mouser.enabled:
             return
         # Try to configure the plug-in
@@ -345,10 +345,12 @@ class api_mouser(distributor_class):
                 dd.url = data['ProductDetailUrl']
                 dd.part_num = data['MouserPartNumber']
                 dd.qty_avail = 0
-                debug_detailed('Availability: '+data['Availability'])
-                res_stock = in_stock_re_1.match(data['Availability'])
+                availability = data['Availability']
+                debug_detailed('Availability: '+availability)
+                dd.qty_avail_comment = availability
+                res_stock = in_stock_re_1.match(availability)
                 if not res_stock:
-                    res_stock = in_stock_re_2.match(data['Availability'])
+                    res_stock = in_stock_re_2.match(availability)
                 debug_detailed('- Search for stock: {}'.format(res_stock))
                 if res_stock:
                     dd.qty_avail = int(res_stock.group(1))
@@ -378,13 +380,5 @@ class api_mouser(distributor_class):
             raise KiCostError(msg, ERR_SCRAPE)
         return set([DIST_NAME])
 
-    @staticmethod
-    def from_environment(options, overwrite):
-        ''' Configuration from the environment. '''
-        # Configure the module from the environment
-        # The command line will overwrite it using set_options()
-        for k, v in ENV_OPS.items():
-            api_mouser._set_from_env(v, os.getenv(k), options, overwrite, api_mouser.config_options)
-
 
 distributor_class.register(api_mouser, 100)
