@@ -29,7 +29,6 @@ __webpage__ = 'https://github.com/set-soft'
 __company__ = 'Instituto Nacional de Tecnologia Industrial - Argentina'
 
 # Libraries.
-import os
 import sys
 import pprint
 import difflib
@@ -49,7 +48,7 @@ else:
 # KiCost definitions.
 from .. import KiCostError, DistData, W_NOINFO, ERR_SCRAPE, W_APIFAIL
 # Distributors definitions.
-from .distributor import distributor_class, QueryCache
+from .distributor import distributor_class, QueryCache, hide_secrets
 from .log__ import debug_overview, debug_obsessive, debug_full, is_debug_full, warning
 
 # Specs known by KiCost
@@ -61,10 +60,6 @@ SPEC_NAMES = {'tolerance': 'tolerance',
               'temperature coefficient': 'temp_coeff'}
 
 DIST_NAME = 'tme'
-ENV_OPS = {'TME_TOKEN': 'token',
-           'TME_APP_SECRET': 'app_secret',
-           'TME_CACHE_TTL': 'cache_ttl'}
-
 BASE_URL = 'https://api.tme.eu'
 MAX_PARTS_PER_QUERY = 10
 
@@ -266,6 +261,8 @@ class api_tme(distributor_class):
     app_secret = None
     country = 'US'
     language = 'EN'
+    env_prefix = 'TME'
+    env_ops = {}
 
     @staticmethod
     def configure(ops):
@@ -290,7 +287,7 @@ class api_tme(distributor_class):
             warning(W_APIFAIL, "Can't enable TME without a `token` and an `app_secret`")
             api_tme.enabled = False
         debug_obsessive('TME API configured to enabled {} token {} app_secret {} path {}'.
-                        format(api_tme.enabled, api_tme.token, api_tme.app_secret, cache_path))
+                        format(api_tme.enabled, hide_secrets(api_tme.token), hide_secrets(api_tme.app_secret), cache_path))
         if not api_tme.enabled:
             return
         # Configure the cache
@@ -368,6 +365,8 @@ class api_tme(distributor_class):
             dd.moq = data['MinAmount']
             dd.qty_increment = data['Multiples']
             dd.url = data['ProductInformationPage']
+            if dd.url and dd.url.startswith('//'):
+                dd.url = 'https:'+dd.url
             dd.part_num = part_stock
             dd.qty_avail = data['Amount']
             dd.currency = o.currency
@@ -403,14 +402,6 @@ class api_tme(distributor_class):
             raise KiCostError(msg, ERR_SCRAPE)
         return set([DIST_NAME])
 
-    @staticmethod
-    def from_environment(options, overwrite):
-        ''' Configuration from the environment. '''
-        # Configure the module from the environment
-        # The command line will overwrite it using set_options()
-        for k, v in ENV_OPS.items():
-            api_tme._set_from_env(v, os.getenv(k), options, overwrite, api_tme.config_options)
-
 
 # Ok, this is special case ... we should add others
 MANF_CHANGES = {'fairchild': 'onsemi'}
