@@ -28,10 +28,14 @@ __author__ = 'Salvador Eduardo Tropea'
 __webpage__ = 'https://github.com/set-soft/'
 __company__ = 'INTI-CMNB - Argentina'
 
+import re
 import copy
 import os
 import logging
-import tqdm
+try:
+    import tqdm
+except ImportError:
+    pass
 # QueryCache dependencies:
 import pickle
 import time
@@ -42,6 +46,14 @@ from .distributors_info import distributors_info
 __all__ = ['distributor_class']
 
 
+def hide_secrets(secret):
+    ''' Show only the first and the last characters of the key.
+        Also keep the `-` '''
+    if not secret:
+        return secret
+    return secret[0]+re.sub(r'[\d\w]', 'X', secret[1:-1])+secret[-1]
+
+
 class TqdmLoggingHandler(logging.Handler):
     '''Overload the class to write the logging through the `tqdm`.'''
     def __init__(self, stream, level=logging.NOTSET):
@@ -105,6 +117,10 @@ class distributor_class(object):
     label2name = {}
     # Options supported by this API
     config_options = {}
+    # Environment variables to configure this API
+    env_ops = {}
+    # A list of options that we want to hide
+    keys_to_hide = {'client_id', 'client_secret', 'token', 'key', 'app_secret'}
 
     @staticmethod
     def register(api, priority):
@@ -117,6 +133,10 @@ class distributor_class(object):
             index += 1
         distributor_class.registered.insert(index, api)
         distributor_class.priorities.insert(index, priority)
+        # Automatically fill the `env_ops`
+        if api.type != 'local':
+            for name in list(api.config_options.keys())+['cache_ttl', 'cache_path']:
+                api.env_ops[api.env_prefix+'_'+name.upper()] = name
 
     @staticmethod
     def update_distributors(parts, distributors):
@@ -237,13 +257,16 @@ class distributor_class(object):
         ''' Find if an API is enabled '''
         return distributor_class._get_api(api).enabled
 
-    @staticmethod
-    def from_environment(options, overwrite):
-        ''' Default configuration from the environment. Just nothing. '''
-        pass
+    @classmethod
+    def from_environment(cls, options, overwrite):
+        ''' Configuration from the environment. '''
+        # Configure the module from the environment
+        # The command line will overwrite it using set_options()
+        for k, v in cls.env_ops.items():
+            distributor_class._set_from_env(v, os.getenv(k), options, overwrite, cls.name, cls.keys_to_hide, cls.config_options)
 
     @staticmethod
-    def _set_from_env(key, value, options, overwrite, d_types=None):
+    def _set_from_env(key, value, options, overwrite, name, hide, d_types=None):
         ''' Helper function to implement `from_environment`. '''
         if value is not None and (overwrite or key not in options):
             if d_types:
@@ -255,6 +278,11 @@ class distributor_class(object):
                     tp = tp[0]
                 # This is a cast
                 value = tp(value)
+            if distributor_class.logger.getEffectiveLevel() <= DEBUG_OBSESSIVE:
+                val = value
+                if key in hide:
+                    val = hide_secrets(value)
+                distributor_class.logger.log(DEBUG_OBSESSIVE, 'Overwriting {}.{} = {}'.format(name, key, val))
             options[key] = value
 
     @staticmethod
